#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nonempty-vector
version:              0.2.4
visibility:           public
id:                   nonempty-vector-0.2.4-A518f77wZRMJnxUY8tOFpZ
key:                  nonempty-vector-0.2.4-A518f77wZRMJnxUY8tOFpZ
license:              BSD-3-Clause
copyright:            (c) 2019-2024 Emily Pillmore <emilypi@cohomolo.gy>
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/nonempty-vector
synopsis:             Non-empty vectors
description:          Performant, non-empty mutable and immutable vectors
category:             Data
abi:                  88fdde32adab0556d9ffc5e3c1ceb7ef
exposed:              True
exposed-modules:
    Data.Vector.NonEmpty Data.Vector.NonEmpty.Internal
    Data.Vector.NonEmpty.Mutable

import-dirs:          /usr/lib/ghc-9.6.6/site-local/nonempty-vector-0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nonempty-vector-0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nonempty-vector-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nonempty-vector
hs-libraries:         HSnonempty-vector-0.2.4-A518f77wZRMJnxUY8tOFpZ
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:
    /usr/share/doc/haskell-nonempty-vector/html/nonempty-vector.haddock

haddock-html:         /usr/share/doc/haskell-nonempty-vector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

